==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/content_manager.lang.inc.php <==
<?php
/**
 * content_manager.lang.inc.php 2020-4-1
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = array(
	'BADGE_STATUS_NOT_ACTIVE'            => 'nicht sichtbar',
	'BADGE_STATUS_SOME_ACTIVE'           => 'teilw. sichtbar',
	'CONFIRM_DELETE'                     => 'Wollen Sie den Content wirklich löschen ?',
	'CONFIRM_DELETE_HEADLINE'            => 'Löschen?',
	'CONTENT_GROUP_ID'                   => 'Content Group ID',
	'CONTENT_NOTE'                       => 'Content markiert mit <font color="#ff0000">*</font> gehört zum System und kann nicht gelöscht werden!',
	'CONTENT_TITLE'                      => 'Content',
	'CREATE_MATRIX'                      => 'Matrix erzeugen',
	'DELETE_CONTENT_ERROR_TEXT'          => 'Der gewählte Content konnte leider nicht gelöscht werden',
	'DELETE_CONTENT_ERROR_TITLE'         => 'Content konnte nicht gelöscht werden',
	'DESCRIPTION_CONTENT'                => 'Inhaltsseite',
	'DESCRIPTION_FILE'                   => 'Skript/Datei',
	'DESCRIPTION_LINK'                   => 'Externe Verlinkung',
	'DESCRIPTION_PRODUCT_CONTENT_FILE'   => 'Datei',
	'DESCRIPTION_PRODUCT_CONTENT_LINK'   => 'Externe Verlinkung',
	'DESCRIPTION_PRODUCT_CONTENT_TEXT'   => 'Text',
	'DOWNLOAD_FILE_LABEL'                => 'Als Download',
	'DOWNLOAD_FILE_TEXT'                 => 'Wählen Sie hier optional eine Datei zum Content aus, die diesem z. B. als PDF-Datei entspricht.',
	'ELEMENT_TYPE'                       => 'Elementart',
	'ELEMENT_TYPE_INFO'                  => 'Inhalt',
	'ERROR_COMMENT'                      => 'Bitte geben Sie eine Dateibeschreibung ein!',
	'ERROR_FILE'                         => 'Falsches Dateiformat (nur .html, .htm, .xhtml, .xml, .txt, .js, .pdf)',
	'ERROR_TITLE'                        => 'Bitte geben Sie einen Titel ein!',
	'GM_ERROR_CONTENT_GROUP_ID_EXISTS'   => 'Die eingegebene Sprachgruppe existiert bereits. Wählen Sie eine noch nicht vergebene Sprachgruppe wie z.B. "{ID}". Ihre Eingaben wurden dennoch abgespeichert.',
	'GM_LINK'                            => 'Link',
	'GM_LINK_BLANK'                      => 'in neuem Fenster öffnen',
	'GM_LINK_TOP'                        => 'in selbem Fenster öffnen',
	'GM_META_DESCRIPTION'                => 'Meta Description',
	'GM_META_KEYWORDS'                   => 'Meta Keywords',
	'GM_META_TITLE'                      => 'Meta Title',
	'GM_ROBOTS_ENTRY'                    => 'Eintrag in robots.txt (disallow)',
	'GM_SITEMAP_CHANGEFREQ'              => 'Änderungsfrequenz in der Sitemap',
	'GM_SITEMAP_ENTRY'                   => 'In die Sitemap aufnehmen',
	'GM_SITEMAP_PRIORITY'                => 'Priorität in der Sitemap',
	'GM_TEXT_URL_REWRITE'                => 'URL Rewrite',
	'GM_TEXT_URL_REWRITE_CONTENT_INFO'   => 'Hier können Sie einen Link zum Content unabhängig vom Titel, Überschrift und URL Keywords definieren.',
	'GM_URL_KEYWORDS'                    => 'URL Keywords',
	'GM_WARNING_CONTENT_GROUP_ID_EXISTS' => 'Die eingegebene Sprachgruppe existiert bereits. Wählen Sie eine noch nicht vergebene Sprachgruppe wie z.B. "{ID}"',
	'HEADING_BOXES'                      => 'Boxen',
    'HEADING_STYLEEDIT'                  => 'StyleEdit',
	'HEADING_CONTENT'                    => 'Seiten Content',
	'HEADING_FILE'                       => 'Skriptdatei',
	'HEADING_FOOTER'                     => 'Footer',
	'HEADING_GROUP_CHECK'                => 'Kundengruppe',
	'HEADING_HEADER'                     => 'Header',
	'HEADING_HOME_PAGE'                  => 'Startseite',
	'HEADING_INFO_BOX'                   => 'Informationen Box',
    'HEADING_ADDITIONAL'                 => 'Weitere Seiten',
	'HEADING_INFO_PAGES'                 => 'Mehr über...',
	'HEADING_LINK'                       => 'Verlinkung',
	'HEADING_MAIN_CATEGORIES'            => 'Hauptkategorien',
	'HEADING_OTHERS'                     => 'Sonstige',
	'HEADING_PRODUCTS_CONTENT'           => 'Artikel Content',
	'HEADING_SECONDARY_NAVIGATION'       => 'Sekundärnavigation',
	'HEADING_SUB_TITLE'                  => 'Hilfsprogramme',
	'HEADING_TITLE'                      => 'Content Manager',
	'HEADING_WITHDRAWAL'                 => 'Widerruf',
	'INTERNAL_NAME'                      => 'Interner Name',
	'LABEL_ADDRESS'                      => 'Linkadresse',
	'LABEL_NAME'                         => 'Interner Name',
	'LABEL_OPEN_NEW_WINDOW'              => 'In neuem Fenster öffnen',
	'LABEL_PRODUCT_CONTENT_FILE'         => 'Datei',
	'LABEL_PRODUCT_CONTENT_LINK'         => 'Link',
	'LABEL_PRODUCT_CONTENT_TEXT'         => 'Text',
	'LABEL_PRODUCT_CONTENT_TYPE'         => 'Content-Typ',
	'LABEL_SHOW_FOR_PRODUCT'             => 'Anzeigen für Artikel',
	'LABEL_TITLE'                        => 'Titel',
	'LABLE_GROUPCHECK_ADMIN'             => 'Admin',
	'LABLE_GROUPCHECK_ALL'               => 'Alle',
	'LABLE_GROUPCHECK_GUEST'             => 'Gast',
	'LABLE_GROUPCHECK_MERCHANT'          => 'Händler',
	'LABLE_GROUPCHECK_NEW_CUSTOMER'      => 'Neuer Kunde',
	'NEW_CONTENT_TITLE'                  => 'Neuer Content',
	'OPENGRAPH_IMAGE'                    => 'Bild für soziale Medien (og:image)',
	'PAGE_TITLE_ELEMENTS'                => 'Elemente',
	'PAGE_TITLE_PAGES'                   => 'Seiten',
	'PAGE_TITLE_PRODUCT_CONTENTS'        => 'Artikelinhalte',
	'PAGE_TYPE'                          => 'Seitenart',
	'PAGE_TYPE_INFO'                     => 'Inhaltsseite',
	'PAGE_TYPE_LINK'                     => 'Verlinkung',
	'PAGE_TYPE_SCRIPT'                   => 'Skriptdatei',
	'SHOW_IN'                            => 'Anzeigen in',
	'TABLE_HEADING_CONTENT_ACTION'       => 'Aktion',
	'TABLE_HEADING_CONTENT_BOX'          => 'Position',
	'TABLE_HEADING_CONTENT_FILE'         => 'Datei',
	'TABLE_HEADING_CONTENT_FILESIZE'     => 'Dateigröße',
	'TABLE_HEADING_CONTENT_GROUP'        => 'ID',
	'TABLE_HEADING_CONTENT_HITS'         => 'Hits',
	'TABLE_HEADING_CONTENT_ID'           => 'Link ID',
	'TABLE_HEADING_CONTENT_LINK'         => 'Link',
	'TABLE_HEADING_CONTENT_NAME'         => 'Name/Dateiname',
	'TABLE_HEADING_CONTENT_SORT'         => 'Reihenfolge',
	'TABLE_HEADING_CONTENT_STATUS'       => 'sichtbar',
	'TABLE_HEADING_CONTENT_TITLE'        => 'Titel',
	'TABLE_HEADING_LANGUAGE'             => 'Sprache',
	'TABLE_HEADING_PRODUCTS'             => 'Artikel',
	'TABLE_HEADING_PRODUCTS_CONTENT_ID'  => 'ID',
	'TABLE_HEADING_PRODUCTS_ID'          => 'ID',
	'TEXT_CHOOSE_FILE'                   => 'Datei wählen',
	'TEXT_CHOOSE_FILE_DESC'              => 'Sie können ebenfals eine bereits verwendete Datei aus der Liste auswählen.',
	'TEXT_CHOOSE_FILE_SERVER'            => '(Falls Sie Ihre Dateien selbst via FTP auf ihren Server gespeichert haben <i>(media/content)</i>, können Sie hier die Datei auswählen.',
	'TEXT_CONTENT'                       => 'Inhalt',
	'TEXT_CONTENT_DESCRIPTION'           => 'Mit dem Content Manager haben Sie die Möglichkeit, jeden beliebige Dateityp einem Artikel hinzuzufügen.<br />Z. B. Artikelbeschreibungen, Handbücher, technische Datenblätter, Hörproben usw..<br />Diese Elemente werden in der Artikeldetailansicht angezeigt.',
	'TEXT_CURRENT_FILE'                  => 'Aktuelle Datei:',
	'TEXT_DELETE'                        => 'Löschen',
	'TEXT_EDIT'                          => 'Bearbeiten',
	'TEXT_EXTERNAL_LINK_INFO'            => 'ist ein externer Link der nicht als Vorschau angezeigt werden kann.',
	'TEXT_FILE_DESC'                     => 'Beschreibung:',
	'TEXT_FILE_DESCRIPTION'              => '<b>Info:</b><br />Sie haben ebenfalls die Möglichkeit eine <b>.html</b> oder <b>.htm</b> Datei als Content einzubinden.<br /> Falls Sie eine Datei auswählen oder hochladen, wird der Text im Textfeld ignoriert.',
	'TEXT_FILE_FLAG'                     => 'Position',
	'TEXT_FILENAME'                      => 'Benutze Datei:',
	'TEXT_GROUP'                         => 'ID',
	'TEXT_GROUP_DESC'                    => ' Mit dieser ID verknüpfen Sie gleiche Themen unterschiedlicher Sprachen miteinander.',
	'TEXT_HEADING'                       => 'Überschrift',
	'TEXT_LANGUAGE'                      => 'Sprache',
	'TEXT_LINK'                          => 'Link',
	'TEXT_NO'                            => 'Nein',
	'TEXT_NO_CONTENT'                    => 'Keine Einträge vorhanden',
	'TEXT_NO_FILE'                       => 'Auswahl löschen',
	'TEXT_PARENT'                        => 'Hauptdokument:',
	'TEXT_PARENT_DESCRIPTION'            => 'Diesem Dokument zuweisen',
	'TEXT_PREVIEW'                       => 'Vorschau',
	'TEXT_PRODUCT'                       => 'Produkte',
	'TEXT_SELECT'                        => '-Bitte wählen-',
	'TEXT_SELECT_NONE'                   => 'kein Teaser Slider',
	'TEXT_SORT_ORDER'                    => 'Sortierung',
	'TEXT_SORTING'                       => 'Sortierung',
	'TEXT_SORTING_FAILED'                => 'Neue Sortierung konnte nicht gespeichert werden.',
	'TEXT_STATUS'                        => 'sichtbar',
	'TEXT_STATUS_DESCRIPTION'            => 'wenn ausgewählt, wird Link bzw. Zusatzbox zum Content angezeigt',
	'TEXT_TITLE'                         => 'Name',
	'TEXT_TITLE_FILE'                    => 'Titel oder Dateiname',
	'TEXT_UPLOAD_FILE'                   => 'Datei hochladen',
	'TEXT_UPLOAD_FILE_LOCAL'             => '(von Ihrem lokalen System)',
	'TEXT_YES'                           => 'Ja',
	'TITLE_ALWAYS'                       => 'Immer',
	'TITLE_CONTENT_SLIDER'               => ' Content Teaser-Slider',
	'TITLE_DAILY'                        => 'Täglich',
	'TITLE_HOURLY'                       => 'Stündlich',
	'TITLE_MONTHLY'                      => 'Monatlich',
	'TITLE_NEVER'                        => 'Nie',
	'TITLE_WEEKLY'                       => 'Wöchentlich',
	'TITLE_YEARLY'                       => 'Jährlich',
	'TUTORIAL_INFO'                      => 'Elemente, die in diesem Bereich angelegt werden, sind nicht sofort im Shop sichtbar und müssen erst durch Anpassung des entsprechenden Templates eingebunden werden. Ein entsprechendes Tutorial gibt es',
	'TUTORIAL_INFO_LINK_TEXT'            => 'hier.',
	'USED_SPACE'                         => 'Verwendeter Speicherplatz: ',
	'WITHDRAWAL_FORM_FILE_LABEL'         => 'Muster-Widerrufsformular',
	'WITHDRAWAL_FORM_FILE_TEXT'          => 'Falls Sie nicht das Standard-Muster-Widerrufsformular nutzen möchten, können Sie hier ein alternatives Dokument auswählen.',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/content_manager.lang.inc.php <==
<?php
/**
 * content_manager.lang.inc.php 2020-06-09
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = array(
	'BADGE_STATUS_NOT_ACTIVE'            => 'nicht sichtbar',
	'BADGE_STATUS_SOME_ACTIVE'           => 'teilw. sichtbar',
	'CONFIRM_DELETE'                     => 'Willst du den Content wirklich löschen ?',
	'CONFIRM_DELETE_HEADLINE'            => 'Löschen?',
	'CONTENT_GROUP_ID'                   => 'Content Group ID',
	'CONTENT_NOTE'                       => 'Der mit <font color="#ff0000">*</font> markierte Content gehört zum System und kann nicht gelöscht werden!',
	'CONTENT_TITLE'                      => 'Content',
	'CREATE_MATRIX'                      => 'Matrix erzeugen',
	'DELETE_CONTENT_ERROR_TEXT'          => 'Der gewählte Content konnte leider nicht gelöscht werden',
	'DELETE_CONTENT_ERROR_TITLE'         => 'Content konnte nicht gelöscht werden',
	'DESCRIPTION_CONTENT'                => 'Inhaltsseite',
	'DESCRIPTION_FILE'                   => 'Skript/Datei',
	'DESCRIPTION_LINK'                   => 'Externe Verlinkung',
	'DESCRIPTION_PRODUCT_CONTENT_FILE'   => 'Datei',
	'DESCRIPTION_PRODUCT_CONTENT_LINK'   => 'Externe Verlinkung',
	'DESCRIPTION_PRODUCT_CONTENT_TEXT'   => 'Text',
	'DOWNLOAD_FILE_LABEL'                => 'Als Download',
	'DOWNLOAD_FILE_TEXT'                 => 'Wähle hier optional eine Datei zum Content aus, die diesem z.B. als PDF-Datei entspricht.',
	'ELEMENT_TYPE'                       => 'Elementart',
	'ELEMENT_TYPE_INFO'                  => 'Inhalt',
	'ERROR_COMMENT'                      => 'Bitte gib eine Dateibeschreibung ein!',
	'ERROR_FILE'                         => 'Falsches Dateiformat (nur .html, .htm, .xhtml, .xml, .txt, .js, .pdf)',
	'ERROR_TITLE'                        => 'Bitte gib einen Titel ein!',
	'GM_ERROR_CONTENT_GROUP_ID_EXISTS'   => 'Die eingegebene Sprachgruppe existiert bereits. Wähle eine noch nicht vergebene Sprachgruppe wie z.B. "{ID}". Deine Eingaben wurden dennoch abgespeichert.',
	'GM_LINK'                            => 'Link',
	'GM_LINK_BLANK'                      => 'In neuem Fenster öffnen',
	'GM_LINK_TOP'                        => 'Im selben Fenster öffnen',
	'GM_META_DESCRIPTION'                => 'Meta Description',
	'GM_META_KEYWORDS'                   => 'Meta Keywords',
	'GM_META_TITLE'                      => 'Meta Title',
	'GM_ROBOTS_ENTRY'                    => 'SEO Indexierung sperren (noindex Header)',
	'GM_SITEMAP_CHANGEFREQ'              => 'Änderungsfrequenz in der Sitemap',
	'GM_SITEMAP_ENTRY'                   => 'In die Sitemap aufnehmen',
	'GM_SITEMAP_PRIORITY'                => 'Priorität in der Sitemap',
	'GM_TEXT_URL_REWRITE'                => 'URL Rewrite',
	'GM_TEXT_URL_REWRITE_CONTENT_INFO'   => 'Hier kannst du einen Link zum Content unabhängig von Titel, Überschrift und URL Keywords definieren.',
	'GM_URL_KEYWORDS'                    => 'URL Keywords',
	'GM_WARNING_CONTENT_GROUP_ID_EXISTS' => 'Die eingegebene Sprachgruppe existiert bereits. Wähle eine noch nicht vergebene Sprachgruppe wie z.B. "{ID}"',
	'HEADING_BOXES'                      => 'Boxen',
    'HEADING_STYLEEDIT'                  => 'StyleEdit',
	'HEADING_CONTENT'                    => 'Seiten Content',
	'HEADING_FILE'                       => 'Skriptdatei',
	'HEADING_FOOTER'                     => 'Footer',
	'HEADING_GROUP_CHECK'                => 'Kundengruppe',
	'HEADING_HEADER'                     => 'Header',
	'HEADING_HOME_PAGE'                  => 'Startseite',
	'HEADING_INFO_BOX'                   => 'Informationen Box',
    'HEADING_ADDITIONAL'                 => 'Weitere Seiten',
	'HEADING_INFO_PAGES'                 => 'Mehr über...',
	'HEADING_LINK'                       => 'Verlinkung',
	'HEADING_MAIN_CATEGORIES'            => 'Hauptkategorien',
	'HEADING_OTHERS'                     => 'Sonstige',
	'HEADING_PRODUCTS_CONTENT'           => 'Artikel Content',
	'HEADING_SECONDARY_NAVIGATION'       => 'Sekundärnavigation',
	'HEADING_SUB_TITLE'                  => 'Hilfsprogramme',
	'HEADING_TITLE'                      => 'Content Manager',
	'HEADING_WITHDRAWAL'                 => 'Widerruf',
	'INTERNAL_NAME'                      => 'Interner Name',
	'LABEL_ADDRESS'                      => 'Linkadresse',
	'LABEL_NAME'                         => 'Interner Name',
	'LABEL_OPEN_NEW_WINDOW'              => 'In neuem Fenster öffnen',
	'LABEL_PRODUCT_CONTENT_FILE'         => 'Datei',
	'LABEL_PRODUCT_CONTENT_LINK'         => 'Link',
	'LABEL_PRODUCT_CONTENT_TEXT'         => 'Text',
	'LABEL_PRODUCT_CONTENT_TYPE'         => 'Content-Typ',
	'LABEL_SHOW_FOR_PRODUCT'             => 'Anzeigen für Artikel',
	'LABEL_TITLE'                        => 'Titel',
	'LABLE_GROUPCHECK_ADMIN'             => 'Admin',
	'LABLE_GROUPCHECK_ALL'               => 'Alle',
	'LABLE_GROUPCHECK_GUEST'             => 'Gast',
	'LABLE_GROUPCHECK_MERCHANT'          => 'Händler',
	'LABLE_GROUPCHECK_NEW_CUSTOMER'      => 'Neuer Kunde',
	'NEW_CONTENT_TITLE'                  => 'Neuer Content',
	'OPENGRAPH_IMAGE'                    => 'Bild für soziale Medien (og:image)',
	'PAGE_TITLE_ELEMENTS'                => 'Elemente',
	'PAGE_TITLE_PAGES'                   => 'Seiten',
	'PAGE_TITLE_PRODUCT_CONTENTS'        => 'Artikelinhalte',
	'PAGE_TYPE'                          => 'Seitenart',
	'PAGE_TYPE_INFO'                     => 'Inhaltsseite',
	'PAGE_TYPE_LINK'                     => 'Verlinkung',
	'PAGE_TYPE_SCRIPT'                   => 'Skriptdatei',
	'SHOW_IN'                            => 'Anzeigen in',
	'TABLE_HEADING_CONTENT_ACTION'       => 'Aktion',
	'TABLE_HEADING_CONTENT_BOX'          => 'Position',
	'TABLE_HEADING_CONTENT_FILE'         => 'Datei',
	'TABLE_HEADING_CONTENT_FILESIZE'     => 'Dateigröße',
	'TABLE_HEADING_CONTENT_GROUP'        => 'ID',
	'TABLE_HEADING_CONTENT_HITS'         => 'Hits',
	'TABLE_HEADING_CONTENT_ID'           => 'Link ID',
	'TABLE_HEADING_CONTENT_LINK'         => 'Link',
	'TABLE_HEADING_CONTENT_NAME'         => 'Name/Dateiname',
	'TABLE_HEADING_CONTENT_SORT'         => 'Reihenfolge',
	'TABLE_HEADING_CONTENT_STATUS'       => 'sichtbar',
	'TABLE_HEADING_CONTENT_TITLE'        => 'Titel',
	'TABLE_HEADING_LANGUAGE'             => 'Sprache',
	'TABLE_HEADING_PRODUCTS'             => 'Artikel',
	'TABLE_HEADING_PRODUCTS_CONTENT_ID'  => 'ID',
	'TABLE_HEADING_PRODUCTS_ID'          => 'ID',
	'TEXT_CHOOSE_FILE'                   => 'Datei wählen',
	'TEXT_CHOOSE_FILE_DESC'              => 'Du kannst ebenfalls eine bereits verwendete Datei aus der Liste auswählen.',
	'TEXT_CHOOSE_FILE_SERVER'            => '(Falls du deine Dateien selbst via FTP auf deinen Server übertragen hast <i>(media/content)</i>, kannst du sie hier auswählen.',
	'TEXT_CONTENT'                       => 'Inhalt',
	'TEXT_CONTENT_DESCRIPTION'           => 'Mit dem Content Manager hast du die Möglichkeit, jeden beliebigen Dateityp einem Artikel hinzuzufügen.<br />Z. B. Artikelbeschreibungen, Handbücher, technische Datenblätter, Hörproben usw..<br />Diese Elemente werden in der Artikeldetailansicht angezeigt.',
	'TEXT_CURRENT_FILE'                  => 'Aktuelle Datei:',
	'TEXT_DELETE'                        => 'Löschen',
	'TEXT_EDIT'                          => 'Bearbeiten',
	'TEXT_EXTERNAL_LINK_INFO'            => 'ist ein externer Link, der nicht als Vorschau angezeigt werden kann.',
	'TEXT_FILE_DESC'                     => 'Beschreibung:',
	'TEXT_FILE_DESCRIPTION'              => '<b>Info:</b><br />Du hast ebenfalls die Möglichkeit, eine <b>.html</b> oder <b>.htm</b> Datei als Content einzubinden.<br /> Falls du eine Datei auswählst oder hochlädst, wird der Text im Textfeld ignoriert.',
	'TEXT_FILE_FLAG'                     => 'Position',
	'TEXT_FILENAME'                      => 'Benutze Datei:',
	'TEXT_GROUP'                         => 'ID',
	'TEXT_GROUP_DESC'                    => 'Mit dieser ID verknüpfst du gleiche Themen unterschiedlicher Sprachen miteinander.',
	'TEXT_HEADING'                       => 'Überschrift',
	'TEXT_LANGUAGE'                      => 'Sprache',
	'TEXT_LINK'                          => 'Link',
	'TEXT_NO'                            => 'Nein',
	'TEXT_NO_CONTENT'                    => 'Keine Einträge vorhanden',
	'TEXT_NO_FILE'                       => 'Auswahl löschen',
	'TEXT_PARENT'                        => 'Hauptdokument:',
	'TEXT_PARENT_DESCRIPTION'            => 'Diesem Dokument zuweisen',
	'TEXT_PREVIEW'                       => 'Vorschau',
	'TEXT_PRODUCT'                       => 'Produkte',
	'TEXT_SELECT'                        => '-Bitte wählen-',
	'TEXT_SELECT_NONE'                   => 'kein Teaser Slider',
	'TEXT_SORT_ORDER'                    => 'Sortierung',
	'TEXT_SORTING'                       => 'Sortierung',
	'TEXT_SORTING_FAILED'                => 'Neue Sortierung konnte nicht gespeichert werden.',
	'TEXT_STATUS'                        => 'Sichtbar',
	'TEXT_STATUS_DESCRIPTION'            => 'Wenn ausgewählt, wird Link bzw. Zusatzbox zum Content angezeigt',
	'TEXT_TITLE'                         => 'Name',
	'TEXT_TITLE_FILE'                    => 'Titel oder Dateiname',
	'TEXT_UPLOAD_FILE'                   => 'Datei hochladen',
	'TEXT_UPLOAD_FILE_LOCAL'             => '(von deinem lokalen System)',
	'TEXT_YES'                           => 'Ja',
	'TITLE_ALWAYS'                       => 'Immer',
	'TITLE_CONTENT_SLIDER'               => 'Content Teaser-Slider',
	'TITLE_DAILY'                        => 'Täglich',
	'TITLE_HOURLY'                       => 'Stündlich',
	'TITLE_MONTHLY'                      => 'Monatlich',
	'TITLE_NEVER'                        => 'Nie',
	'TITLE_WEEKLY'                       => 'Wöchentlich',
	'TITLE_YEARLY'                       => 'Jährlich',
	'TUTORIAL_INFO'                      => 'Elemente, die in diesem Bereich angelegt werden, sind nicht sofort im Shop sichtbar und müssen erst durch Anpassung des entsprechenden Templates eingebunden werden. Ein entsprechendes Tutorial gibt es',
	'TUTORIAL_INFO_LINK_TEXT'            => 'hier.',
	'USED_SPACE'                         => 'Verwendeter Speicherplatz: ',
	'WITHDRAWAL_FORM_FILE_LABEL'         => 'Muster-Widerrufsformular',
	'WITHDRAWAL_FORM_FILE_TEXT'          => 'Falls du nicht das Standard-Muster-Widerrufsformular nutzen möchtest, kannst du hier ein alternatives Dokument auswählen.',
    'BUTTON_OPEN_PAGE_IN_SE4'            => 'Seite im StyleEdit4 aufrufen',
    'COPY_LINK'                          => 'Link Kopieren',
    'COPIED'                             => 'Kopiert',
);
